@@ -1,4 +1,4 @@
-from src.statement_dl import main
+from statement_dl import main
 
 if __name__ == "__main__":
     main()
